==> haskell-streaming-commons-0.1.17-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: streaming-commons
version: 0.1.17
id: streaming-commons-0.1.17-6k51SJxMSKy6BYhtadRCnX
key: streaming-commons-0.1.17-6k51SJxMSKy6BYhtadRCnX
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/streaming-commons
synopsis: Common lower-level functions needed by various streaming data libraries
description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.
category: Data
author: Michael Snoyman, Emanuel Borsboom
exposed: True
exposed-modules:
    Data.Streaming.Blaze Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer
    Data.Streaming.ByteString.Builder.Class Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel
hidden-modules: Data.Text.Internal.Unsafe.Char
                Data.Text.Internal.Unsafe.Shift Data.Text.Internal.Encoding.Utf8
                Data.Text.Internal.Encoding.Utf16 Data.Text.Internal.Encoding.Utf32
abi: 7844cfc882f2b8ef1f33d470201dabba
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/streaming-commons-0.1.17
library-dirs: /usr/lib/ghc-8.0.1/site-local/streaming-commons-0.1.17
data-dir: /usr/share/i386-linux-ghc-8.0.1/streaming-commons-0.1.17
hs-libraries: HSstreaming-commons-0.1.17-6k51SJxMSKy6BYhtadRCnX
depends:
    array-0.5.1.1 async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4 base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    directory-1.2.6.2 network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    process-1.4.2.0 random-1.1-54KmMHXjttlERYcr1mvsAe
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unix-2.7.2.0 zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock
haddock-html: /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-streaming-commons-0.1.17-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: streaming-commons
version: 0.1.17
id: streaming-commons-0.1.17-2RhPlNIoNU5IoFWI4FKVKo
key: streaming-commons-0.1.17-2RhPlNIoNU5IoFWI4FKVKo
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/streaming-commons
synopsis: Common lower-level functions needed by various streaming data libraries
description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.
category: Data
author: Michael Snoyman, Emanuel Borsboom
exposed: True
exposed-modules:
    Data.Streaming.Blaze Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer
    Data.Streaming.ByteString.Builder.Class Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel
hidden-modules: Data.Text.Internal.Unsafe.Char
                Data.Text.Internal.Unsafe.Shift Data.Text.Internal.Encoding.Utf8
                Data.Text.Internal.Encoding.Utf16 Data.Text.Internal.Encoding.Utf32
abi: d80d7413e9245cbb7afc2e9b21c4fc11
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/streaming-commons-0.1.17
library-dirs: /usr/lib/ghc-8.0.1/site-local/streaming-commons-0.1.17
data-dir: /usr/share/i386-linux-ghc-8.0.1/streaming-commons-0.1.17
hs-libraries: HSstreaming-commons-0.1.17-2RhPlNIoNU5IoFWI4FKVKo
depends:
    array-0.5.1.1 async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4 base-4.9.0.0
    blaze-builder-0.4.0.2-J9puUMdRFvA3rt0D0pNg3S bytestring-0.10.8.1
    directory-1.2.6.2 network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    process-1.4.2.0 random-1.1-54KmMHXjttlERYcr1mvsAe
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v transformers-0.5.2.0
    unix-2.7.2.0 zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock
haddock-html: /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
